@@ -1,12 +1,16 @@
 ;(function(){
   var map = {
+  "commitId": "1c1bd444a9265fc92bb277e61442baa8e03145a7",
+  "branchName": "release",
+  "buildTime": "Fri, 04 Nov 2022 09:26:48 GMT",
+  "buildVersion": "5.1.138",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.59e38391.css",
-    "@zoom/client-scheduler/static/css/index.884397a0.css"
+    "@zoom/client-scheduler/static/css/chunk-vendors.7f57ae19.css",
+    "@zoom/client-scheduler/static/css/index.e12145da.css"
   ],
   "js": [
-    "@zoom/client-scheduler/static/js/chunk-vendors.cd16d45c.js",
-    "@zoom/client-scheduler/static/js/index.e01d66af.js"
+    "@zoom/client-scheduler/static/js/chunk-vendors.c9bce98f.js",
+    "@zoom/client-scheduler/static/js/index.1ffda21c.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
